<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>प्रॉक्सी का प्रकार</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>आईपी पता</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>पोर्ट</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>वैकल्पिक</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>संचित करें</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>डिस्कनेक्ट है</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>संचित करें</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>कनेक्ट हो रहा है </translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>डिस्कनेक्ट है</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Wired Connection %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>हॉटस्पॉट</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Connection %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>नया वीपीएन</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>वीपीएन का प्रकार</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>ओपेनवीपीएन</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>ओपनकनेक्ट </translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>निर्यात करें</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>नेटवर्क </translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>नेटवर्क विवरण</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>सिस्टम प्रॉक्सी </translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>केबल नेटवर्क</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>केबल रहित नेटवर्क</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>वीपीएन</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>नेटवर्क कनेक्शन जोड़ें </translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>छुपे नेटवर्क से जुड़ें</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE कनेक्शन बनाएँ</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>वीपीएन स्थिति</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>वीपीएन बनाएँ</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>वीपीएन आयात करें</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>प्रॉक्सी का प्रकार</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>विन्यास यूआरएल</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>आईपी पता</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>पोर्ट</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>हॉटस्पॉट</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>इंटरफेस </translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>बैंड </translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>आईपीवी4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>प्राथमिक DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>आईपीवी6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>नेटवर्क उपसर्ग </translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>गति</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>ईथरनेट </translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>उपकरण MAC ऐड्रेस</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>क्लोन किया MAC ऐड्रेस</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU को कस्टमाइज करें </translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>एमटीयू</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>नाम</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>हॉटस्पॉट</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>सेटिंग्स जोड़ें</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>आईपी पता</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>नेटवर्क उपसर्ग </translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>आईपीवी4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>आईपीवी6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>स्वतः</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>मैनुअल </translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>अनदेखा करें </translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>आईपी पता</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>केवल अनुकूल साधानो पर लागू किया जाएगा</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>विधि</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>नेटवर्क उपसर्ग </translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>नेटवर्क </translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>आईपी विरोधाभास</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>विधि</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>आईपीवी4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>स्वतः</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>मैनुअल </translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>आईपीवी6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>अनदेखा करें </translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>नेटवर्क विवरण</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>वीपीएन</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>सिस्टम प्रॉक्सी </translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>नेटवर्क विवरण</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>नेटवर्क </translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>आईपी विरोधाभास</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>बंद किया हुआ है</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>मैनुअल </translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>स्वतः</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>सेवा</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>कोई BSD डेटा संपीड़न नहीं</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>कोई डिफ्लेट डेटा संपीड़न नहीं </translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>कोई TCP हेडर संपीड़न नहीं</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>कोई प्रोटोकोल फील्ड संपीड़न नहीं </translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>कोई ऐड्रेस/कंट्रोल संपीड़न नहीं</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP ईको पैकेट्स भेजें</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE का इस्तेमाल करें </translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-बिट एमपीपीई</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>स्थितिपूर्वक एमपीपीई</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE कनेक्शन बनाएँ</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>सिस्टम प्रॉक्सी </translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>संचित करें</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>प्रॉक्सी का प्रकार</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>मैनुअल </translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>स्वतः</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>वैकल्पिक</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>पोर्ट</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>एचटीटीपी प्रॉक्सि</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>एचटीटीपीएस प्रॉक्सि</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>एफ़टीपी प्रॉक्सि</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>ऊपर दिए गए होस्ट एवं डोमेन के लिए विन्यस्त प्रॉक्सी सेटिंग्स को अनदेखा करें</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>विन्यास यूआरएल</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>सुरक्षा</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>तीव्र </translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>टनल युक्त TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>सुरक्षित EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>बंद किया हुआ है</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>गुमनाम </translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>प्रमाणीकृत </translation>
    </message>
    <message>
        <source>Both</source>
        <translation>दोनों</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>स्वतः</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>संस्करण 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>संस्करण 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP ऑथ</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>पहचान</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>पासवर्ड ओप्शन्स</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>निजी कुंजी </translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>यूजर  Cert</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>अज्ञात आईडी</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>प्रोविजनिंग </translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>पीएसी फ़ाइल</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>इनर ऑथ </translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>पीईएपी संस्करण</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>निजी कूटशब्द</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>कोई नहीं</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 पर्सनल </translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>सुरक्षा</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>कुंजी</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>सुरक्षा आवश्यक </translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>कोई नहीं</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 पर्सनल </translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 एंटरप्राइज </translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>सुरक्षा</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>कुंजी</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN ऐडवांस्ड </translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>गेटवे पोर्ट कस्टमाइज करें </translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>गेटवे पोर्ट </translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>रीनिगोशिएशन इंटरवल कस्टमाइज करें </translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>रिनिगोशिएशन इंटरवल </translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>टनल MTU को कस्टमाइज करें </translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>एमटीयू</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP फ्रैगमेंट साइज को कस्टमाइज करें </translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP फ्रैगमेंट साइज</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>टनल TCP MSS को प्रतिबंधित करें </translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>रिमोट होस्ट को रैंडमाइज करें </translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN ऐडवांस्ड </translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>सिस्को (डिफॉल्ट)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>नेटस्क्रीन </translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>सुरक्षित (डिफॉल्ट)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>कमजोर</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कोई नहीं</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T उपलब्ध होने पर (डिफॉल्ट)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T हमेशा </translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>सिस्को UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>बंद किया हुआ है</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH ग्रुप 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH ग्रुप 2 (डिफॉल्ट)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH ग्रुप 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>सर्वर (डिफॉल्ट)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH ग्रुप 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>डोमैन</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>वेंडर </translation>
    </message>
    <message>
        <source>Version</source>
        <translation>संस्करण</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>एंक्रिप्शन </translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal Mode</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH ग्रुप </translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>गोपनीयता आगे बढ़ाएं  </translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>स्थानीय पोर्ट</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>डेड पीयर डिटेक्शन निष्क्रिय करें</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPसेक</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec को सक्रिय करें </translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>समूह का नाम</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>समूह आईडी</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>प्री-शेयर्ड-की </translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>फेज़1 एल्गोरिथ्म्स</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>फेज़2 एल्गोरिथ्म्स</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>वीपीएन</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>प्रॉक्सि</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>सिस्को सिक्योर डेस्कटॉप ट्रोजन की अनुमति दें </translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD स्क्रिप्ट</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>यूजर  Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>निजी कुंजी </translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>की पासफ्रेज के लिए FSID </translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>वीपीएन</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>सर्टिफिकेट्स (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>पासवर्ड के साथ सर्टिफिकेट (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>स्टेटिक-की </translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>सहेजा गया</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>पूंछें</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>आवश्यक नहीं </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>ऑथ टाइप </translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>यूजर  Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>निजी कुंजी </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>पासवर्ड ओप्शन्स</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>निजी कूटशब्द</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>कस्टमाइज्ड की-डाइरेक्शन </translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>की-डाइरेक्शन </translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>रिमोट आईपी</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>स्थानीय आईपी</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>वीपीएन पीपीपी</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>सभी उपलब्ध (डिफॉल्ट)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-बिट (कम सुरक्षित)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-बिट (सर्वाधिक सुरक्षित)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 प्रमाणीकरण से इंकार करें </translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>कोई BSD डेटा संपीड़न नहीं</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>कोई डिफ्लेट डेटा संपीड़न नहीं </translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>कोई TCP हेडर संपीड़न नहीं</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>कोई प्रोटोकोल फील्ड संपीड़न नहीं </translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>कोई ऐड्रेस/कंट्रोल संपीड़न नहीं</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP ईको पैकेट्स भेजें</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE का इस्तेमाल करें </translation>
    </message>
    <message>
        <source>Security</source>
        <translation>सुरक्षा</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>स्थितिपूर्वक एमपीपीई</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>वीपीएन स्थिति</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>वीपीएन बनाएँ</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>वीपीएन आयात करें</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>आयात करते समय त्रुटि</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>ठीक है</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not Required</source>
        <translation>आवश्यक नहीं </translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>सॉक्स </translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>प्रॉक्सी का प्रकार</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>सर्वर आईपी</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>पोर्ट</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>विफल होने पर अनिश्चित समय तक प्रयास करें  </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>सीए फ़ाइल</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>वीपीएन सुरक्षा</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>डिफ़ॉल्ट</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कोई नहीं</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>साइफ़र </translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC ऑथ </translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>वीपीएन</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>सहेजा गया</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>पूंछें</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>आवश्यक नहीं </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>पासवर्ड ओप्शन्स</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>एनटी डोमैन</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server IP</source>
        <translation>सर्वर आईपी</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>पोर्ट</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>वीपीएन</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>निजी कुंजी </translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>प्री-शेयर्ड-की </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>ऑथ टाइप </translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>यूजर  Cert</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Request an Inner IP Address</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Enforce UDP Encapsulation</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Use IP Compression</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS प्रमाणीकरण </translation>
    </message>
    <message>
        <source>Default</source>
        <translation>डिफ़ॉल्ट</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>क्लाइंट </translation>
    </message>
    <message>
        <source>Server</source>
        <translation>सर्वर</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>विषय मैच </translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>रिमोट सर्ट टाइप </translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>कुंजी फ़ाइल</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>कस्टमाइज्ड की-डाइरेक्शन </translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>की-डाइरेक्शन </translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>वीपीएन</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>सहेजा गया</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>पूंछें</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>आवश्यक नहीं </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>पासवर्ड ओप्शन्स</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>समूह का नाम</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>समूह का कूटशब्द</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>हाइब्रिड ऑथेंटिकेशन का इस्तेमाल करें</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>सीए फ़ाइल</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>नेटवर्क कनेक्शन जोड़ें </translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>सेटिंग्स चुनें</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>छुपे नेटवर्क से जुड़ें</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>उपकरण MAC ऐड्रेस</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU को कस्टमाइज करें </translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>एमटीयू</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>हॉटस्पॉट</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>प्रोटोकॉल </translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>सुरक्षा प्रकार</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>चैनल </translation>
    </message>
    <message>
        <source>Band</source>
        <translation>बैंड </translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>इंटरफेस </translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>आईपीवी4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>प्राथमिक DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>आईपीवी6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>नेटवर्क उपसर्ग </translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>गति</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>उपकरण निष्क्रिय है</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>कनेक्ट है परंतु नेटवर्क हेतु अभिगम नहीं है </translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>कनेक्ट नहीं है</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>नेटवर्क केबल हटी हुई है</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>कनेक्ट हो रहा है </translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>प्रमाणीकृत किया जा रहा है</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP अड्रेस प्राप्त किया जा रहा है</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>कनेक्ट है </translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>डिस्कनेक्ट है</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>आईपी विरोधाभास</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>विफल रहा</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>नेटवर्क पता प्राप्त करना जारी</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>केबल नेटवर्क</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>केबल नेटवर्क %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>केबल रहित नेटवर्क</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>केबल रहित नेटवर्क %1</translation>
    </message>
</context>
</TS>